about summary refs log tree commit diff
path: root/pkgs/development/haskell-modules/configuration-ghc-8.8.x.nix
diff options
context:
space:
mode:
authorsternenseemann <sternenseemann@systemli.org>2023-07-02 13:32:18 +0200
committersternenseemann <sternenseemann@systemli.org>2023-07-02 14:22:20 +0200
commit6cc8bbe4b62b8a2005c78093220751bcdb804922 (patch)
tree5c5a4570a28a60d2cb3727a355c7d78799a3c785 /pkgs/development/haskell-modules/configuration-ghc-8.8.x.nix
parent84627b0594b55669cdb18dcb7d5fe89a00e79fce (diff)
downloadnixlib-6cc8bbe4b62b8a2005c78093220751bcdb804922.tar
nixlib-6cc8bbe4b62b8a2005c78093220751bcdb804922.tar.gz
nixlib-6cc8bbe4b62b8a2005c78093220751bcdb804922.tar.bz2
nixlib-6cc8bbe4b62b8a2005c78093220751bcdb804922.tar.lz
nixlib-6cc8bbe4b62b8a2005c78093220751bcdb804922.tar.xz
nixlib-6cc8bbe4b62b8a2005c78093220751bcdb804922.tar.zst
nixlib-6cc8bbe4b62b8a2005c78093220751bcdb804922.zip
haskell.packages.{ghc88,ghc810}.OneTuple: depend on foldable1-classes-compat
For GHC >= 9.0, foldable1-classes-compat is a test only dependency. For GHC < 9.0,
OneTuple also depends on it. It is important to add it to the library's build
depends as well, so it gets propagated properly to builds of packages that depend
on base-compat-batteries (or foldable1-classes-compat will appear as broken to
Cabal).
Diffstat (limited to 'pkgs/development/haskell-modules/configuration-ghc-8.8.x.nix')
-rw-r--r--pkgs/development/haskell-modules/configuration-ghc-8.8.x.nix8
1 files changed, 5 insertions, 3 deletions
diff --git a/pkgs/development/haskell-modules/configuration-ghc-8.8.x.nix b/pkgs/development/haskell-modules/configuration-ghc-8.8.x.nix
index 756b66237e62..ad9b8e5a1d11 100644
--- a/pkgs/development/haskell-modules/configuration-ghc-8.8.x.nix
+++ b/pkgs/development/haskell-modules/configuration-ghc-8.8.x.nix
@@ -148,10 +148,12 @@ self: super: {
   # has a restrictive lower bound on Cabal
   fourmolu = doJailbreak super.fourmolu;
 
-  # OneTuple needs hashable instead of ghc-prim for GHC < 9
-  OneTuple = super.OneTuple.override {
+  # OneTuple needs hashable (instead of ghc-prim) and foldable1-classes-compat for GHC < 9
+  OneTuple = addBuildDepends [
+    self.foldable1-classes-compat
+  ] (super.OneTuple.override {
     ghc-prim = self.hashable;
-  };
+  });
 
   # Temporarily disabled blaze-textual for GHC >= 9.0 causing hackage2nix ignoring it
   # https://github.com/paul-rouse/mysql-simple/blob/872604f87044ff6d1a240d9819a16c2bdf4ed8f5/Database/MySQL/Internal/Blaze.hs#L4-L10